/*
 * @(#)CreateArchive.java
 *
 * Copyright (c) 1998 Karl Moss. All Rights Reserved.
 *
 * You may study, use, modify, and distribute this software for any
 * purpose provided that this copyright notice appears in all copies.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @version 1.0
 * @date    07Feb98
 *
 */

package javaservlets.rollcall;

/**
  * <p>This simple application will use the RollCall class to
  * find all of the class file dependency for a given set of
  * classes. If an archive file is specified it will be created
  * and all of the dependent files will be added.
  */

public class CreateArchive
{
  public static void main(String args[])
    {
      // Create a new object and process
      
      CreateArchive ca = new CreateArchive();
      ca.create(args);
    }

  public void create(String args[])
    {
      // Get a list of all of the class files to check. Any
      // arguments given without a switch '-' will be considered
      // a class file

      String files[] = getFiles(args);

      if (files == null) {
        System.out.println("No class files specified");
        showHelp();
        return;
      }

      // Get the archive to create, if given

      String archive = getArg(args, "-a");

      // Create a new RollCall object

      RollCall rollCall = new RollCall();
      
      try {

        // Set the class files to check
        
        rollCall.setClasses(files);

        // Set the archive to create
        
        rollCall.setArchive(archive);

        // Check all strings, if necessary
        rollCall.setCheckStrings(isArg(args, "-c"));
        
        // Perform the check and create the archive, if necessary.
        
        rollCall.start();
      }
      catch (Exception ex) {
        ex.printStackTrace();
      }
    }

  /*
   * <p>Display help for this application
   */

  private void showHelp()
    {
      System.out.println("\nCreateArchive" +
                         " - Create archive with class dependencies");
      System.out.println("\nCommand format is:\n");
      System.out.println("CreateArchive" +
                         " <classname> [<classname> ...] " +
                         " [-a<archive>] [-c]");
      System.out.println("\nWhere");
      System.out.println("\tclassname = class file to check " +
                         "(without the .class extension)");
      System.out.println("\tarchive = name of the archive to create");
      System.out.println("\t-c directs CreateArchive to check all Strings");
    }
  
  /*
   * <p>Return a list of files to check. Command line arguments
   * with no switch '-' will be considered a file. If there
   * are no files found, return null.
   */
  
  private String[] getFiles(String args[])
    {
      String files[] = null;
      
      if (args != null) {
        
        // We've got some arguments. Create a temporary vector
        // to hold the files we find

        java.util.Vector temp = new java.util.Vector();

        // Process the arguments. If an argument does not
        // start with a switch '-', add it to our vector

        for (int i = 0; i < args.length; i++) {
          if (!args[i].startsWith("-")) {
            temp.addElement(args[i]);
          }
        }

        // Now our vector contains all of the files that we
        // found. Create a String array to hold them.

        if (temp.size() > 0) {
          files = new String[temp.size()];
          for (int i = 0; i < temp.size(); i++) {
            files[i] = (String) temp.elementAt(i);
          }
        }
      }
      return files;
    }

  /*
   * <p>Return the argument for the given switch. Returns null
   * if the switch was not found.
   */

  private String getArg(String args[], String cmd)
    {
      String s = null;

      if (args != null) {
        // Loop through the arguments and find the first
        // one that starts with the given switch.

        for (int i = 0; i < args.length; i++) {
          if (args[i].startsWith(cmd)) {

            // Make sure there is data with the switch
            
            if (args[i].length() > cmd.length()) {

              // Get the data associated with the switch
              
              s = args[i].substring(cmd.length());
            }
          }
        }
      }
      
      return s;
    }

  /**
    * <p>Determines if the command line switch is present
    */
  private boolean isArg(String args[], String cmd)
    {
      if (args != null) {
        // Loop through the arguments and find the first
        // one that starts with the given switch.
        
        for (int i = 0; i < args.length; i++) {
          if (args[i].startsWith(cmd)) {
            return true;
          }
        }
      }
      return false;
    }
}
